@@ -103,11 +103,13 @@
 ;;;         (* 1024 mem)))))
 ;;; --------------------------------------------------------------------------------
 
-(define *cload-cflags* "") 
+(define *cload-cflags* (if (provided? 'clang) "-fPIC" ""))
 (define *cload-ldflags* "")
 (if (not (defined? '*cload-directory*))
     (define *cload-directory* ""))
 
+(define *cload-c-compiler* (if (provided? 'gcc) "gcc" (if (provided? 'clang) "clang" "cc")))
+
 
 (define-macro (defvar name value) 
   `(if (not (defined? ',name)) 
@@ -206,7 +208,11 @@
 
   (set! c-define-output-file-counter (+ c-define-output-file-counter 1))
 
-  (let ((file-name (string-append *cload-directory* (or output-name (format #f "temp-s7-output-~D" c-define-output-file-counter)))))
+  (let ((file-name (string-append *cload-directory* 
+				  (if (and (> (length *cload-directory*) 0)
+					   (not (char=? (string-ref *cload-directory* (- (length *cload-directory*) 1)) #\/)))
+				      "/" "")
+				  (or output-name (format #f "temp-s7-output-~D" c-define-output-file-counter)))))
     (let ((c-file-name (string-append file-name ".c"))
 	  (o-file-name (string-append file-name ".o"))
 	  (so-file-name (string-append file-name ".so"))
@@ -415,8 +421,8 @@
 		   (set! local-name "_i")
 		   (format p "static s7_int ~A~A(void) {return(~A());}~%" func-name local-name func-name))
 		  ((double)
-		   (set! local-name "_i_d")
-		   (format p "static s7_int ~A~A(s7_double x) {return(~A(x));}~%" func-name local-name func-name))
+		   (set! local-name "_i_7d")
+		   (format p "static s7_int ~A~A(s7_scheme *sc, s7_double x) {return(~A(x));}~%" func-name local-name func-name))
 		  ((int)
 		   (if (= num-args 1)
 		       (begin
@@ -490,7 +496,7 @@
 	   (format p "  ~A~%" init-str))
 	 (reverse inits))
 	
-	;; "constants" -- actually variables in s7 because we want them to be local to the current environment
+	;; "constants" -- actually variables in s7 because we want them to be local to the current environment (this comment is obsolete)
 	(if (pair? constants)
 	    (begin
 	      (format p "~%")
@@ -563,14 +569,16 @@
 	  (format p "~%  /* double optimizer connections */~%")
 	  (for-each
 	   (lambda (f)
-	     (format p "  s7_set~A_function(s7_name_to_value(sc, ~S), ~A~A);~%" (caddr f) (cadr f) (car f) (caddr f)))
+	     (unless (defined? (symbol (cadr f)) (rootlet))
+	       (format p "  s7_set~A_function(s7_name_to_value(sc, ~S), ~A~A);~%" (caddr f) (cadr f) (car f) (caddr f))))
 	   double-funcs))
 	
 	(when (pair? int-funcs)
 	  (format p "~%  /* int optimizer connections */~%")
 	  (for-each
 	   (lambda (f)
-	     (format p "  s7_set~A_function(s7_name_to_value(sc, ~S), ~A~A);~%" (caddr f) (cadr f) (car f) (caddr f)))
+	     (unless (defined? (symbol (cadr f)) (rootlet))
+	       (format p "  s7_set~A_function(s7_name_to_value(sc, ~S), ~A~A);~%" (caddr f) (cadr f) (car f) (caddr f))))
 	   int-funcs))
 	
 	(format p "}~%")
@@ -580,10 +588,10 @@
 	
 	(cond ((provided? 'osx)
 	       ;; I assume the caller is also compiled with these flags?
-	       (system (format #f "gcc -c ~A -o ~A ~A ~A" 
-			       c-file-name o-file-name *cload-cflags* cflags))
-	       (system (format #f "gcc ~A -o ~A -dynamic -bundle -undefined suppress -flat_namespace ~A ~A" 
-			       o-file-name so-file-name *cload-ldflags* ldflags)))
+	       (system (format #f "~A -c ~A -o ~A ~A ~A" 
+			       *cload-c-compiler* c-file-name o-file-name *cload-cflags* cflags))
+	       (system (format #f "~A ~A -o ~A -dynamic -bundle -undefined suppress -flat_namespace ~A ~A" 
+			       *cload-c-compiler* o-file-name so-file-name *cload-ldflags* ldflags)))
 	      
 	      ((provided? 'freebsd)
 	       (system (format #f "cc -fPIC -c ~A -o ~A ~A ~A" 
@@ -592,10 +600,10 @@
 			       o-file-name so-file-name *cload-ldflags* ldflags)))
 	      
 	      ((provided? 'openbsd)
-	       (system (format #f "cc -fPIC -ftrampolines -c ~A -o ~A ~A ~A" 
-			       c-file-name o-file-name *cload-cflags* cflags))
-	       (system (format #f "cc ~A -shared -o ~A ~A ~A" 
-			       o-file-name so-file-name *cload-ldflags* ldflags)))
+	       (system (format #f "~A -fPIC -ftrampolines -c ~A -o ~A ~A ~A" 
+			       *cload-c-compiler* c-file-name o-file-name *cload-cflags* cflags))
+	       (system (format #f "~A ~A -shared -o ~A ~A ~A" 
+			       *cload-c-compiler* o-file-name so-file-name *cload-ldflags* ldflags)))
 	      
 	      ((provided? 'sunpro_c) ; just guessing here...
 	       (system (format #f "cc -c ~A -o ~A ~A ~A" 
@@ -603,13 +611,11 @@
 	       (system (format #f "cc ~A -G -o ~A ~A ~A" 
 			       o-file-name so-file-name *cload-ldflags* ldflags)))
 	      
-	      ;; what about clang?  Maybe use cc below, not gcc (and in osx case above)
-	      
 	      (else
-	       (system (format #f "gcc -fPIC -c ~A -o ~A ~A ~A" 
-			       c-file-name o-file-name *cload-cflags* cflags))
-	       (system (format #f "gcc ~A -shared -o ~A ~A ~A" 
-			       o-file-name so-file-name *cload-ldflags* ldflags)))))
+	       (system (format #f "~A -fPIC -c ~A -o ~A ~A ~A" 
+			       *cload-c-compiler* c-file-name o-file-name *cload-cflags* cflags))
+	       (system (format #f "~A ~A -shared -o ~A ~A ~A" 
+			       *cload-c-compiler* o-file-name so-file-name *cload-ldflags* ldflags)))))
       
       (define handle-declaration 
 	(let ()
