@@ -57,57 +57,57 @@
 	    (old-color (foreground-color snd chn))
 	    (axinf (axis-info snd chn))
 	    (old-axinf (channel-property 'rms-axis-info snd chn))
-	    (cr (make-cairo (car (channel-widgets snd chn)))))
+	    (cr (and (provided? 'gtk4) ((channel-widgets snd chn) 17))))
 	
-	(if (equal? axinf old-axinf)                    ; the previously calculated lines can be re-used
-	    (begin
-	      (set! (foreground-color snd chn) red)
-	      (draw-lines (channel-property 'rms-lines snd chn) snd chn time-graph cr)
-	      (set! (foreground-color snd chn) old-color))
-	    (let ((start (max 0 (- left rms-size))))
-	      (let ((xdata (pack-x-info axinf))
-		    (ydata (pack-y-info axinf))
-		    (reader (make-sampler start snd chn))
-		    (rms (make-moving-rms rms-size))
-		    (x0 0)
-		    (y0 0)
-		    (line-ctr 2)
-		    (lines (make-vector (* 2 (- (+ (axinf 12) 1) (axinf 10))) 0)))
-		(dynamic-wind
-		    (lambda ()
-		      (set! (foreground-color snd chn) red))
-		    (lambda ()
-		      (if (< start left)                 ; check previous samples to get first rms value
-			  (do ((i start (+ 1 i))) 
-			      ((= i left))
-			    (moving-rms rms (reader))))
-		      (let ((first-sample (next-sample reader)))
-			(set! x0 (grf-it (* left sr) xdata))
-			(set! y0 (grf-it first-sample ydata)))
-		      (set! (lines 0) x0)                ; first graph point
-		      (set! (lines 1) y0)
-		      (do ((i (+ left 1) (+ 1 i)))       ; loop through all samples calling moving-rms
-			  ((= i right))
-			(let ((x1 (grf-it (* i sr) xdata))
-			      (y (moving-rms rms (next-sample reader))))
-			  (if (> x1 x0)                 ; very often many samples are represented by one pixel
-			      (let ((y1 (grf-it y ydata)))
-				(set! (lines line-ctr) x1)
-				(set! (lines (+ 1 line-ctr)) y1)
-				(set! line-ctr (+ line-ctr 2))
-				(set! x0 x1)
-				(set! y0 y1)))))      ; else should we do "max" here? or draw a vertical line from min to max?
-		      (if (< line-ctr (length lines))
-			  (do ((j line-ctr (+ j 2)))       ; off-by-one in vector size calc -- need to pad so we don't get a bogus line to (0, 0)
-			      ((>= j (length lines)))
-			    (set! (lines j) x0)
-			    (set! (lines (+ j 1)) y0)))
-		      (draw-lines lines snd chn time-graph cr)
-		      (set! (channel-property 'rms-lines snd chn) lines)  ; save current data for possible redisplay
-		      (set! (channel-property 'rms-axis-info snd chn) axinf))
-		    (lambda ()
-		      (set! (foreground-color snd chn) old-color))))))
-	(free-cairo cr)))))
+	(when cr
+	  (if (equal? axinf old-axinf)                    ; the previously calculated lines can be re-used
+	      (begin
+		(set! (foreground-color snd chn) red)
+		(draw-lines (channel-property 'rms-lines snd chn) snd chn time-graph cr)
+		(set! (foreground-color snd chn) old-color))
+	      (let ((start (max 0 (- left rms-size))))
+		(let ((xdata (pack-x-info axinf))
+		      (ydata (pack-y-info axinf))
+		      (reader (make-sampler start snd chn))
+		      (rms (make-moving-rms rms-size))
+		      (x0 0)
+		      (y0 0)
+		      (line-ctr 2)
+		      (lines (make-vector (* 2 (- (+ (axinf 12) 1) (axinf 10))) 0)))
+		  (dynamic-wind
+		      (lambda ()
+			(set! (foreground-color snd chn) red))
+		      (lambda ()
+			(if (< start left)                 ; check previous samples to get first rms value
+			    (do ((i start (+ 1 i))) 
+				((= i left))
+			      (moving-rms rms (reader))))
+			(let ((first-sample (next-sample reader)))
+			  (set! x0 (grf-it (* left sr) xdata))
+			  (set! y0 (grf-it first-sample ydata)))
+			(set! (lines 0) x0)                ; first graph point
+			(set! (lines 1) y0)
+			(do ((i (+ left 1) (+ 1 i)))       ; loop through all samples calling moving-rms
+			    ((= i right))
+			  (let ((x1 (grf-it (* i sr) xdata))
+				(y (moving-rms rms (next-sample reader))))
+			    (if (> x1 x0)                 ; very often many samples are represented by one pixel
+				(let ((y1 (grf-it y ydata)))
+				  (set! (lines line-ctr) x1)
+				  (set! (lines (+ 1 line-ctr)) y1)
+				  (set! line-ctr (+ line-ctr 2))
+				  (set! x0 x1)
+				  (set! y0 y1)))))      ; else should we do "max" here? or draw a vertical line from min to max?
+			(if (< line-ctr (length lines))
+			    (do ((j line-ctr (+ j 2)))       ; off-by-one in vector size calc -- need to pad so we don't get a bogus line to (0, 0)
+				((>= j (length lines)))
+			      (set! (lines j) x0)
+			      (set! (lines (+ j 1)) y0)))
+			(draw-lines lines snd chn time-graph cr)
+			(set! (channel-property 'rms-lines snd chn) lines)  ; save current data for possible redisplay
+			(set! (channel-property 'rms-axis-info snd chn) axinf))
+		      (lambda ()
+			(set! (foreground-color snd chn) old-color)))))))))))
     
 ;; (hook-push after-graph-hook (lambda (hook) (overlay-rms-env (hook 'snd) (hook 'chn))))
 
@@ -120,8 +120,9 @@ whenever they're in the current view."))
 	    (right (right-sample snd chn))
 	    (end (+ beg dur))
 	    (old-color (foreground-color snd chn))
-	    (cr (make-cairo (car (channel-widgets snd chn)))))
-	(when (and (< left end)
+	    (cr (and (provided? 'gtk4) ((channel-widgets snd chn) 17))))
+	(when (and cr
+		   (< left end)
 		   (> right beg))
 	  (let ((data (make-graph-data snd chn)))
 	    (if (float-vector? data)
@@ -139,8 +140,7 @@ whenever they're in the current view."))
 		       (new-high-data (float-vector-subseq (cadr data) left-bin right-bin)))
 		  (set! (foreground-color snd chn) color)
 		  (graph-data (list new-low-data new-high-data) snd chn copy-context left-bin right-bin (time-graph-style snd chn) cr)
-		  (set! (foreground-color snd chn) old-color)))))
-	(free-cairo cr)))))
+		  (set! (foreground-color snd chn) old-color)))))))))
 
 
 (define (display-samples-in-color hook)
@@ -189,18 +189,17 @@ whenever they're in the current view."))
 	    (let ((rinc (/ (- 1.0 (car clist)) (+ edits 1)))
 		  (ginc (/ (- 1.0 (cadr clist)) (+ edits 1)))
 		  (binc (/ (- 1.0 (caddr clist)) (+ edits 1)))
-		  (cr (make-cairo (car (channel-widgets snd chn))))) 
-	      (do ((pos 0 (+ 1 pos))
-		   (re (- 1.0 rinc) (- re rinc))
-		   (ge (- 1.0 ginc) (- ge ginc))
-		   (be (- 1.0 binc) (- be binc)))
-		  ((> pos edits))
-		(let ((data (make-graph-data snd chn pos)))
-		  (set! (foreground-color snd chn) (make-color re ge be))
-		  (graph-data data snd chn copy-context #f #f (time-graph-style snd chn) cr)))
-	      (set! (foreground-color snd chn) old-color)
-	      (free-cairo cr))))))))
-
+		  (cr (and (provided? 'gtk4) ((channel-widgets snd chn) 17))))
+	      (when cr
+		(do ((pos 0 (+ 1 pos))
+		     (re (- 1.0 rinc) (- re rinc))
+		     (ge (- 1.0 ginc) (- ge ginc))
+		     (be (- 1.0 binc) (- be binc)))
+		    ((> pos edits))
+		  (let ((data (make-graph-data snd chn pos)))
+		    (set! (foreground-color snd chn) (make-color re ge be))
+		    (graph-data data snd chn copy-context #f #f (time-graph-style snd chn) cr)))
+		(set! (foreground-color snd chn) old-color)))))))))
 
 (define overlay-sounds
   (let ((+documentation+ "(overlay-sounds . args) overlays onto its first argument all subsequent arguments: (overlay-sounds 1 0 3)"))
@@ -213,21 +212,21 @@ whenever they're in the current view."))
 		     (let ((snd (hook 'snd))
 			   (chn (hook 'chn)))
 		       (if (equal? snd base)
-			   (let ((cr (make-cairo (car (channel-widgets snd chn)))))
-			     (for-each 
-			      (lambda (nsnd)
-				(if (and (sound? nsnd)
-					 (> (chans nsnd) chn))
-				    (graph-data (make-graph-data nsnd chn) base chn copy-context #f #f graph-dots cr)))
-			      (cdr args))
-			     (free-cairo cr))))))))))
+			   (let ((cr (and (provided? 'gtk4) ((channel-widgets snd chn) 17))))
+			     (when cr
+			       (for-each 
+				(lambda (nsnd)
+				  (if (and (sound? nsnd)
+					   (> (chans nsnd) chn))
+				      (graph-data (make-graph-data nsnd chn) base chn copy-context #f #f graph-dots cr)))
+				(cdr args))))))))))))
 
 
 (define samples-via-colormap 
   (let ((+documentation+ "(samples-via-colormap snd chn) displays time domain graph using current colormap (just an example of colormap-ref)"))
     (lambda (snd chn)
       (let ((data (make-graph-data snd chn))
-	    (cr (make-cairo (car (channel-widgets snd chn)))))
+	    (cr (and (provided? 'gtk4) ((channel-widgets snd chn) 17))))
 	
 	(define (samples-1 cur-data)
 	  (let ((left (left-sample snd chn))
@@ -255,12 +254,10 @@ whenever they're in the current view."))
 		  (set! y0 y1)))
 	      (set! (foreground-color snd chn) old-color))))
 
-	(if data
-	    (if (float-vector? data)
-		(samples-1 data)
-		(begin
-		  (samples-1 (car data))
-		  (samples-1 (cadr data)))))
-	(free-cairo cr)))))
-
+	(when (and cr data)
+	  (if (float-vector? data)
+	      (samples-1 data)
+	      (begin
+		(samples-1 (car data))
+		(samples-1 (cadr data)))))))))
 
