@@ -29,21 +29,15 @@
   (define (with-mock-wrapper func)
     (lambda (obj)
       (cond ((mock? obj)
-	     (dynamic-wind
-		 coverlets
-		 (lambda ()
-		   (func (obj 'value)))
-		 openlets))
+	     (let-temporarily (((openlets) #f))
+	       (func (obj 'value))))
 
 	    ((not (openlet? obj))
 	     (func obj))
 
 	    ((procedure? obj) ; TODO: and c-pointer? c-object?
-	     (dynamic-wind
-		 coverlets
-		 (lambda ()
-		   (func obj))
-		 openlets))
+	     (let-temporarily (((openlets) #f))
+	       (func obj)))
 
 	    (else
 	     (let ((func-name (string->symbol (object->string func))))
@@ -53,21 +47,25 @@
 
   (define (with-mock-wrapper* func)
     (lambda args
-      (let* ((unknown-openlets #f)
-	     (new-args (map (lambda (arg)
-			      (if (mock? arg)
-				  (arg 'value)
-				  (begin
-				    (if (and (openlet? arg)
-					     (not (procedure? arg))
-					     (not (macro? arg))
-					     (not (c-pointer? arg)))
-					(set! unknown-openlets #t))
-				    arg)))
-			    args)))
+      (let ((unknown-openlets #f)
+	    (new-args ()))
+	(for-each (lambda (arg) ; not map here because (values) should not be ignored: (+ (mock-number 4/3) (values))
+		    (set! new-args
+			  (cons (if (mock? arg)
+				    (arg 'value)
+				    (begin
+				      (if (and (openlet? arg)
+					       (not (procedure? arg))
+					       (not (macro? arg))
+					       (not (c-pointer? arg)))
+					  (set! unknown-openlets #t))
+				      arg))
+				new-args)))
+		  args)
 	(if unknown-openlets
-	    (apply func new-args)
-	    (dynamic-wind coverlets (lambda () (apply func new-args)) openlets)))))
+	    (apply func (reverse new-args))
+	    (let-temporarily (((openlets) #f)) 
+	      (apply func (reverse new-args)))))))
 
   ;; one tricky thing here is that a mock object can be the let of with-let: (with-let (mock-port ...) ...)
   ;;   so a mock object's method can be called even when no argument is a mock object.  Even trickier, the
@@ -475,7 +473,7 @@
 		 'negative?        (with-mock-wrapper #_negative?)
 		 'infinite?        (with-mock-wrapper #_infinite?)
 		 'nan?             (with-mock-wrapper #_nan?)
-		 'append           (with-mock-wrapper* #_append)
+		 ;'append           (with-mock-wrapper* #_append) ;?? (append ... 3 ...) is an error
 		 'magnitude        (with-mock-wrapper #_magnitude)
 		 'angle            (with-mock-wrapper #_angle)
 		 'rationalize      (with-mock-wrapper* #_rationalize)
@@ -867,7 +865,7 @@
 	       (mock-symbol-class
 		(inlet 'equivalent?           (with-mock-wrapper* #_equivalent?)
 		       'gensym?               (with-mock-wrapper #_gensym?)
-		       'append                (with-mock-wrapper* #_append)
+		       ;'append                (with-mock-wrapper* #_append) ;? (append ... 'a ...) is an error
 		       'symbol->string        (with-mock-wrapper #_symbol->string)
 		       'symbol->value         (with-mock-wrapper* #_symbol->value)
 		       'symbol->dynamic-value (with-mock-wrapper #_symbol->dynamic-value)
@@ -1006,7 +1004,7 @@
 		       'output-port?        (with-mock-wrapper #_output-port?)
 		       'port-closed?        (with-mock-wrapper #_port-closed?)
 		       'equivalent?         (with-mock-wrapper* #_equivalent?)
-		       'append              (with-mock-wrapper* #_append)
+		       ;'append              (with-mock-wrapper* #_append) ; ?? (append (open-input-string "asdf")...) is an error
 		       'set-current-output-port (with-mock-wrapper #_set-current-output-port)
 		       'set-current-input-port  (with-mock-wrapper #_set-current-input-port)
 		       'set-current-error-port  (with-mock-wrapper #_set-current-error-port)
