@@ -1,3 +1,5 @@
+(provide 'profile.scm)
+
 (define* (show-profile (n 100))
   (let ((info (*s7* 'profile-info)))
     (if (null? info)
@@ -26,19 +28,10 @@
 		(let ((file (profile-filename key))
 		      (line (profile-line-number key)))
 		  (if (> line 0)
-		      (format *stderr* "~A:~8T~A ~24T~A[~A]: ~48T~A~%" 
+		      (format *stderr* "~A:~8T~A ~20T~A[~A]: ~40T~A~%" 
 			      count 
-			      (if (string? func)
+			      (if (symbol? func)
 				  (format #f " ~A" func)
 				  "")
 			      file line
-			      (if (> (length expr) 60)
-				  (string-append (substring expr 0 56) " ...")
-				  expr)))))))))))
-
-#|
-(define old-version s7-version)
-(define (s7-version)
-  (show-profile)
-  (old-version))
-|#
+			      (object->string expr #t 60)))))))))))
