@@ -3,8 +3,10 @@
 ;;; reimplementation of code formerly in stuff.scm
 
 (provide 'reactive.scm)
+;(set! (*s7* 'gc-stats) #t)
 
 (define (symbol->let symbol env)
+  ;(format *stderr* "symbol->let ~S~%" symbol)
   ;; return let in which symbol lives (not necessarily curlet)
   (if (defined? symbol env #t)
       env	
@@ -45,7 +47,6 @@
 	(else 
 	 (gather-symbols (cdr expr) ce (gather-symbols (car expr) ce lst ignore) ignore))))
 
-
 ;;; c-pointer used to hold symbol+let info so that the lets can be a "weak references"
 (define slot-symbol c-pointer-type)
 (define slot-expr c-pointer-info)
@@ -55,11 +56,13 @@
 
 (define (setter-update cp)            ; cp: (slot var expr env expr-env)
   ;; when var set, all other vars dependent on it need to be set also, watching out for GC'd followers
-  (when (and (let? (slot-env cp))                  ; when slot-env is GC'd, the c-pointer field is set to #f (by the GC)
-	     (let? (slot-expr-env cp)))
-    (let-set! (slot-env cp) 
-	      (slot-symbol cp)
-	      (eval (slot-expr cp) (slot-expr-env cp)))))
+  (when (and (let? (slot-env cp))
+	     (let? (slot-expr-env cp)))     ; when slot-env is GC'd, the c-pointer field is set to #f (by the GC)
+    (let ((val (eval (slot-expr cp) (slot-expr-env cp))))
+      (when (let? (slot-env cp))      ; same as above, but eval may trigger gc
+	(let-set! (slot-env cp)
+		  (slot-symbol cp)
+		  val)))))
 
 
 (define (slot-equal? cp1 cp2)
@@ -81,35 +84,50 @@
 	(setters setters)
 	(cp (slot var expr env expr-env)))
     (lambda (sym val)
+      ;(format *stderr* "make-setter ~S ~S~%" sym val)
       (let-temporarily (((setter (slot-symbol cp) (slot-env cp)) #f))
 			 ;(setter (c-pointer-type cp) (c-pointer-weak1 cp)) #f))
 	(let-set! (slot-env cp) (slot-symbol cp) val) ; set new value without retriggering the setter
 	(for-each setter-update followers)            ; set any variables dependent on var
 	val))))
 
+(define (update-setters setters cp e)
+  ;; add the slot to the followers setter list of each variable in expr
+  (for-each (lambda (s)
+	      (unless (and (setter s e)
+			   (defined? 'followers (funclet (setter s e))))
+		(set! (setter s e) (make-setter s e)))
+	      (let ((setter-followers (let-ref (funclet (setter s e)) 'followers)))
+		(unless (member cp setter-followers slot-equal?)
+		  (let-set! (funclet (setter s e))
+			    'followers
+			    (cons cp setter-followers)))))
+	    setters))
 
-(define-bacro (reactive-set! place value)             ; or maybe macro* with trailing arg: (e (outlet (curlet)))??
+(define (clean-up-setter old-setter old-followers lt place e)
+  ;; if previous set expr, remove it from setters' followers lists
+  (when (and old-setter
+	     (defined? 'followers (funclet old-setter))
+	     (defined? 'setters (funclet old-setter)))
+    (set! old-followers ((funclet old-setter) 'followers))
+    (for-each (lambda (s)
+		(when (and (setter s e)
+			   (defined? 'followers (funclet (setter s e))))
+		  (let ((setter-followers (let-ref (funclet (setter s e)) 'followers)))
+		    (let-set! (funclet (setter s e))
+			      'followers 
+			      (setter-remove (slot place 0 lt e) setter-followers)))))
+	      (let-ref (funclet old-setter) 'setters)))
+  old-followers)
+
+(define-bacro (reactive-set! place value)
   (with-let (inlet 'place place                       ; with-let here gives us control over the names
 		   'value value 
 		   'e (outlet (curlet)))              ; the run-time (calling) environment
     `(let ((old-followers ())
 	   (old-setter (setter ',place))
 	   (lt (symbol->let ',place ,e)))
-
-       ;; if previous set expr, remove it from setters' followers lists
-       (when (and old-setter
-		  (defined? 'followers (funclet old-setter))
-		  (defined? 'setters (funclet old-setter)))
-	 (set! old-followers ((funclet old-setter) 'followers))
-	 (for-each (lambda (s)
-		     (when (and (setter s)
-				(defined? 'followers (funclet (setter s))))
-		       (let ((setter-followers (let-ref (funclet (setter s)) 'followers)))
-			 (let-set! (funclet (setter s))
-				   'followers 
-				   (setter-remove (slot ',place 0 lt ,e) setter-followers)))))
-		   (let-ref (funclet old-setter) 'setters)))
-
+       (set! old-followers (clean-up-setter old-setter old-followers lt ',place ,e))
        ;; set up new setter
        (let ((setters (gather-symbols ',value ,e () ())))
 	 (when (pair? setters)
@@ -117,21 +135,11 @@
 	     (let ((cp (slot ',place expr lt ,e)))
 	       (set! (setter ',place lt)
 		     (make-setter ',place lt old-followers setters expr ,e))
-       
-	       ;; add the slot to the followers setter list of each variable in expr
-	       (for-each (lambda (s)
-			   (unless (and (setter s)
-					(defined? 'followers (funclet (setter s))))
-			     (set! (setter s) (make-setter s (symbol->let s ,e))))
-			   (let ((setter-followers (let-ref (funclet (setter s)) 'followers)))
-			     (unless (member cp setter-followers slot-equal?)
-			       (let-set! (funclet (setter s))
-					 'followers
-					 (cons cp setter-followers)))))
-			 setters)))))
+	       (update-setters setters cp ,e)))))
        (set! ,place ,value))))
 
 
+
 ;; --------------------------------------------------------------------------------
 #|
 (let ()
