@@ -2,9 +2,13 @@
 ;;;
 ;;; (load "repl.scm") ((*repl* 'run))
 
+(set! (*s7* 'history-enabled) #f)
 (provide 'repl.scm)
 (require libc.scm)
 
+(define old-debug (*s7* 'debug))
+(set! (*s7* 'debug) 0)
+
 (unless (defined? '*repl*)
   (define *repl*                    ; environment that holds the REPL functions
     (let ((prompt #f)               ; function to get/set prompt
@@ -15,7 +19,7 @@
 	  (restore-history #f)      ; function to restore history buffer entries from a file
 	  (helpers ())              ; list of functions displaying help strings 
 	  (run #f)                  ; function that fires up a REPL
-	  (top-level-let (sublet (rootlet) :** #f)) ; environment in which evaluation takes place
+	  (top-level-let (sublet (rootlet))) ; environment in which evaluation takes place
 	  (repl-let                 ; environment for keymap functions to access all the REPL innards (cursor-position etc)
 	   
       (with-let (sublet *libc*)
@@ -35,13 +39,13 @@
 			       (string=? text (substring sym 0 text-len)))
 		      (if match
 			  ;; more than one match, save the longest text that all syms match
-			  (let ((min-len (min (string-length match) sym-len)))
-			    (do ((i text-len (+ i 1)))
-				((or (= i min-len)
-				     (not (char=? (match i) (sym i))))
-				 (if (= min-len text-len)
-				     (return text)
-				     (set! match (substring match 0 i))))))
+			  (do ((min-len (min (string-length match) sym-len))
+			       (i text-len (+ i 1)))
+			      ((or (= i min-len)
+				   (not (char=? (match i) (sym i))))
+			       (if (= min-len text-len)
+				   (return text)
+				   (set! match (substring match 0 i)))))
 			  (set! match sym)))))
 		st)
 	       (or match text)))))
@@ -92,54 +96,55 @@
 		     (string=? (vector-ref histbuf i) line))
 		 (and (< i histsize) i))))
 	  
-	  (define history-size (dilambda
-				(lambda ()
-				  histsize)
-				(lambda (new-size)
-				  (unless (= new-size histsize)
-				    (if (<= new-size 0)
-					(error 'out-of-range "new history buffer size must be positive")
-					(let ((new-hist (make-vector new-size ""))
-					      (new-end (min (- new-size 1) histpos)))
-					  (let loop ((oldpos histpos)
-						     (newpos new-end))
-					    (set! (new-hist newpos) (histbuf oldpos))
-					    (set! newpos (- (if (zero? newpos) new-size newpos) 1))
-					    (unless (= newpos new-end)
-					      (set! oldpos (- (if (zero? oldpos) histsize oldpos) 1))
-					      (unless (= oldpos histpos)
-						(loop oldpos newpos))))
-					  (set! histsize new-size)
-					  (set! histpos new-end)
-					  (set! histbuf new-hist)
-					  new-size))))))
+	  (define history-size 
+	    (dilambda
+	     (lambda ()
+	       histsize)
+	     (lambda (new-size)
+	       (unless (= new-size histsize)
+		 (if (<= new-size 0)
+		     (error 'out-of-range "new history buffer size must be positive")
+		     (let ((new-hist (make-vector new-size ""))
+			   (new-end (min (- new-size 1) histpos)))
+		       (let loop ((oldpos histpos)
+				  (newpos new-end))
+			 (set! (new-hist newpos) (histbuf oldpos))
+			 (set! newpos (- (if (zero? newpos) new-size newpos) 1))
+			 (unless (= newpos new-end)
+			   (set! oldpos (- (if (zero? oldpos) histsize oldpos) 1))
+			   (unless (= oldpos histpos)
+			     (loop oldpos newpos))))
+		       (set! histsize new-size)
+		       (set! histpos new-end)
+		       (set! histbuf new-hist)
+		       new-size))))))
+	  
+	  (define (history back)
+	    (let ((i (+ histpos back)))
+	      (copy (histbuf (if (< i 0)
+				 (+ histsize i)
+				 (if (>= i histsize)
+				     (- i histsize)
+				     i))))))
 
-	  (define history (dilambda 
-			   (lambda (back)
-			     (let ((i (+ histpos back)))
-			       (copy (histbuf (if (< i 0)
-						  (+ histsize i)
-						  (if (>= i histsize)
-						      (- i histsize)
-						      i))))))
-			   (lambda (new-line)
-			     (let ((pos (history-member new-line)))
-			       (when (integer? pos)                   ; remove the earlier case, circularly compress the buffer
-				 (when (>= pos histpos)
-				   (do ((i pos (+ i 1)))
-				       ((>= i (- histsize 1)))
-				     (set! (histbuf i) (histbuf (+ i 1))))
-				   (set! (histbuf (- histsize 1)) (histbuf 0))
-				   (set! pos 0))
-				 (do ((i pos (+ i 1)))
-				     ((>= i (- histpos 1)))
-				   (set! (histbuf i) (histbuf (+ i 1))))
-				 (set! histpos (- histpos 1))))
-
-			     (set! (histbuf histpos) (copy new-line))
-			     (set! histpos (+ histpos 1))
-			     (if (= histpos histsize)
-				 (set! histpos 0)))))
+	  (define (set-history! new-line)
+	    (let ((pos (history-member new-line)))
+	      (when (integer? pos)                   ; remove the earlier case, circularly compress the buffer
+		(when (>= pos histpos)
+		  (do ((i pos (+ i 1)))
+		      ((>= i (- histsize 1)))
+		    (set! (histbuf i) (histbuf (+ i 1))))
+		  (set! (histbuf (- histsize 1)) (histbuf 0))
+		  (set! pos 0))
+		(do ((i pos (+ i 1)))
+		    ((>= i (- histpos 1)))
+		  (set! (histbuf i) (histbuf (+ i 1))))
+		(set! histpos (- histpos 1))))
+	    
+	    (set! (histbuf histpos) (copy new-line))
+	    (set! histpos (+ histpos 1))
+	    (if (= histpos histsize)
+		(set! histpos 0)))
 	  
 	  (define (history-help)
 	    (set! (*repl* 'helpers)
@@ -211,70 +216,16 @@
 				(zero? (system (string-append "command -v " var-name " >/dev/null"))))
 		       (set! unbound-case #t)
 		       (if (procedure? ((rootlet) 'system))
-			   (begin
-			     (set! ((*repl* 'top-level-let) '**) (((rootlet) 'system) cur-line #t))
-			     (display ((*repl* 'top-level-let) '**) *stderr*))
-			   (set! ((*repl* 'top-level-let) '**) (system cur-line)))
-		       (set! (h 'result) (symbol " ")))))))
-	    
-	    (define (with-repl-let body)
-	      ;; for multiline edits, we will use *missing-close-paren-hook* rather than try to parse the input ourselves.
-	      (let ((old-badexpr-hook (hook-functions *missing-close-paren-hook*))
-		    (old-unbound-var-hook (hook-functions *unbound-variable-hook*))
-		    (old-eval #f)
-		    (old-eval-string #f)
-		    (old-load #f))
-		
-		;; if the repl's top-level-let is not rootlet, and we load some file into rootlet
-		;;   that (for example) defines a function at its top level, that function's definition
-		;;   env is rootlet.  If we then define something in the repl, it is in the
-		;;   repl's top level.  If we now call the function asking is the new thing defined,
-		;;   it looks in rootlet, not the repl top-level, and says no.
-		;; so, locally redefine these three to use the repl top-level while we're in the repl.
-		;; in addition, for each of these, we need to report missing close parens and so on
-		
-		(let ((repl-hooks
-		       (lambda ()
-			 (set! (hook-functions *missing-close-paren-hook*) (cons badexpr old-badexpr-hook))
-			 (set! (hook-functions *unbound-variable-hook*) (cons shell? old-unbound-var-hook))))
-		
-		      (original-hooks
-		       (lambda ()
-			 (set! unbound-case #f)
-			 (set! (hook-functions *missing-close-paren-hook*) old-badexpr-hook)
-			 (set! (hook-functions *unbound-variable-hook*) old-unbound-var-hook))))
-		
-		  (let ((new-load 
-			 (let ((+documentation+ "this is the repl's load replacement; its default is to use the repl's top-level-let.")
-			       (+signature+ '(values string? let?)))
-			   (lambda* (file (e (*repl* 'top-level-let)))
-			     (dynamic-wind repl-hooks (lambda () (load file e)) original-hooks))))
-			
-			(new-eval 
-			 (let ((+documentation+ "this is the repl's eval replacement; its default is to use the repl's top-level-let.")
-			       (+signature+ '(values list? let?)))
-			   (lambda* (form (e (*repl* 'top-level-let)))
-			     (dynamic-wind repl-hooks (lambda () (eval form e)) original-hooks))))
-			
-			(new-eval-string 
-			 (let ((+documentation+ "this is the repl's eval-string replacement; its default is to use the repl's top-level-let.")
-			       (+signature+ '(values string? let?)))
-			   (lambda* (str (e (*repl* 'top-level-let)))
-			     (dynamic-wind repl-hooks (lambda () (eval-string str e)) original-hooks)))))
-		    
-		    (dynamic-wind
-			(lambda ()
-			  (repl-hooks)
-			  (set! eval new-eval)
-			  (set! eval-string new-eval-string)
-			  (set! load new-load))
-			body
-			(lambda ()
-			  (set! eval old-eval)
-			  (set! eval-string old-eval-string)
-			  (set! load old-load)
-			  (original-hooks)))))))
+			   (set! (h 'result) (((rootlet) 'system) cur-line #f))
+			   (set! (h 'result) #f)))))))
 	    
+	    (define new-eval 
+	      (let ((+documentation+ "this is the repl's eval replacement; its default is to use the repl's top-level-let.")
+		    (+signature+ '(values list? let?)))
+		(lambda* (form (e (*repl* 'top-level-let)))
+		  (let-temporarily (((hook-functions *unbound-variable-hook*) (list shell?)))
+		    (let-temporarily (((*s7* 'history-enabled) #t))
+		      (eval form e))))))
 	    
 	    ;; -------- match parens --------
 	    (define check-parens
@@ -393,20 +344,20 @@
 		     (terminal-fd (fileno stdin)))
 		(format *stderr* "~C[6n" #\escape)
 		(do ((b (read terminal-fd cc 1) (read terminal-fd cc 1)))
-		    ((char=? (c 0) #\escape)))
+		    ((char=? (string-ref c 0) #\escape)))
 		(read terminal-fd cc 1) 
-		(and (char=? (c 0) #\[)
+		(and (char=? (string-ref c 0) #\[)
 		     (let ((y 0)
 			   (x 0))
 		       (do ((b (read terminal-fd cc 1) (read terminal-fd cc 1)))
-			   ((not (char-numeric? (c 0))))
-			 (set! y (- (+ (* 10 y) (char->integer (c 0))) (char->integer #\0))))
-		       (and (char=? (c 0) #\;)
+			   ((not (char-numeric? (string-ref c 0))))
+			 (set! y (- (+ (* 10 y) (char->integer (string-ref c 0))) (char->integer #\0))))
+		       (and (char=? (string-ref c 0) #\;)
 			    (do ((b (read terminal-fd cc 1) (read terminal-fd cc 1)))
-				((not (char-numeric? (c 0)))
-				 (and (char=? (c 0) #\R)
+				((not (char-numeric? (string-ref c 0)))
+				 (and (char=? (string-ref c 0) #\R)
 				      (cons x y)))
-			      (set! x (- (+ (* 10 x) (char->integer (c 0))) (char->integer #\0)))))))))
+			      (set! x (- (+ (* 10 x) (char->integer (string-ref c 0))) (char->integer #\0)))))))))
 	    
 	    (define (cursor-bounds)
 	      (let ((coords (cursor-coords)))
@@ -888,49 +839,59 @@
 			     
 			     ;; we want to add cur-line (copied) to the history buffer
 			     ;;   unless it is an on-going edit (missing close paren)
-			     (catch 'string-read-error
+			     (catch 'string-read-error ; this matches (throw #t 5) -- is this correct?
 			       
 			       (lambda ()
 				 (set! cursor-pos len)
 				 (if (or (= chars 1)
 					 (not (= input-fd terminal-fd)))
 				     (display-lines))
-				 (set! (history) cur-line)
+				 (set-history! cur-line)
 				 (set! m-p-pos 0)
 				 
-				 (with-repl-let
-				  (lambda ()
-				    ;; get the newline out if the expression does not involve a read error
-				    (let ((form (with-input-from-string cur-line #_read)))    ; not libc's read
-				      (newline *stderr*)
-				      (let ((val (eval form (*repl* 'top-level-let))))
-					(if unbound-case
-					    (set! unbound-case #f)
-					    (begin
-					      (format *stderr* "~S~%" val)
-					      ;; this set! of '** has one odd consequence: if val is a lambda expression
-					      ;;   find_closure in s7 will fallback on the current environment trying to
-					      ;;   find an associated name, and the only thing it finds is '**!  So,
-					      ;;   when we type **, we get back **, which seems perverse.  I suppose
-					      ;;   we could trap the string above, see "**" and change to ~W or something.
-					      (set! ((*repl* 'top-level-let) '**) val))))))))
+				 ;; get the newline out if the expression does not involve a read error
+				 (let-temporarily (((hook-functions *missing-close-paren-hook*) (list badexpr)))
+				   (let ((form (with-input-from-string cur-line #_read)))    ; not libc's read
+				     (newline *stderr*)
+				     (let ((val (list (new-eval form (*repl* 'top-level-let))))) ; list, not lambda -- confuses trace!
+				       (if (or (null? val)   ; try to trap (values) -> #<unspecified>
+					       (and (unspecified? (car val))
+						    (null? (cdr val))))
+					   (set! val #<unspecified>)
+					   (set! val (if (pair? (cdr val))
+							 (cons 'values val)
+							 (car val))))
+						 
+				       (if unbound-case
+					   (set! unbound-case #f)
+					   (format *stderr* "~S~%" val))
+				       (eval `(define ,(string->symbol (format #f "<~D>" (+ (length histtop) 1))) ',val) (rootlet))))))
 			       
 			       (lambda (type info)
-				 (pop-history)               ; remove last history entry
-				 (append-newline)
-				 (return))))
+				 (if (eq? type 'string-read-error)
+				     (begin
+				       (pop-history)               ; remove last history entry
+				       (append-newline)
+				       (return))
+				     (apply throw type info)))))   ; re-raise error
 			   
 			   (lambda (type info)
-			     (format *stderr* "~A:" (red "error"))
-			     (if (and (pair? info)
-				      (string? (car info)))
-				 (format *stderr* " ~A" (apply format #f info))
-				 (if (not (null? info))
-				     (format *stderr* " ~A" info)))
-			     (newline *stderr*)))
+			     (with-let (unlet)
+			       (format *stderr* "~A:" (red "error"))
+			       (let ((op (*s7* 'print-length)))
+				 (if (< op 32) (set! (*s7* 'print-length) 32))
+				 (if (and (pair? info)
+					  (string? (car info)))
+				     (format *stderr* " ~A" (apply format #f info))
+				     (if (not (null? info))
+					 (format *stderr* " ~A" info)))
+				 (if (< op 32) (set! (*s7* 'print-length) op)))
+			       (eval `(define ,(string->symbol (format #f "<~D>" (+ (length histtop) 1))) 'error) (rootlet))
+			       (newline *stderr*))))
 			 
 			 (push-line (copy cur-line))
 			 (new-prompt))))))
+
 	    
 	    ;; -------- escaped (Meta/Alt/arrow) keys
 	    (set! (keymap-functions Escape) 
@@ -984,7 +945,7 @@
 		(let ((old-index m-p-pos))
 		  (when (and (zero? m-p-pos) 
 			     (> (length cur-line) 0))
-		    (set! (history) cur-line)
+		    (set-history! cur-line)
 		    (set! m-p-pos -1))
 		  (set! m-p-pos (max (- m-p-pos 1) (- histsize)))
 		  (if (positive? (length (history m-p-pos)))
@@ -1049,8 +1010,8 @@
 	    
 	    ;; -------- emacs --------
 	    (define (emacs-repl)
-	      ;; TODO: use the emacs language server protocol? (not our own rpc stuff or epc), for json, see json.scm 
-	      ;;   probably will need an argument/function? for repl to open the channel or whatever
+	      ;; someday maybe use the language server protocol? (not our own rpc stuff or epc), for json, see json.scm 
+	      ;;   probably will need an argument/function for repl to open the channel or whatever
 	      ;; also this does not resend the entire expression after editing
 	      ;;   and does not notice in-place edits
 	      ;;   can <cr> get entire expr?
@@ -1073,13 +1034,10 @@
 				       ((= (string-length str) 0))
 				     (catch 'string-read-error
 				       (lambda ()
-					 (with-repl-let
-					  (lambda ()
-					    (format *stderr* "~S~%> " (eval-string str (*repl* 'top-level-let)))
-					    (set! str ""))))
+					 (format *stderr* "~S~%> " (eval-string str (*repl* 'top-level-let)))
+					 (set! str ""))
 				       (lambda (type info)
 					 (fgets buf 512 stdin)
-					 ;(format *stderr* "add str: ~S~%" (substring buf 0 (- (strlen buf) 1)))
 					 (set! str (string-append str " " (substring buf 0 (- (strlen buf) 1))))))))
 				 (lambda (type info)
 				   (set! str "")
@@ -1098,9 +1056,10 @@
 		
 		(varlet (*repl* 'top-level-let) 
 		  :exit (let ((+documentation+ "(exit) resets the repl tty and exits the repl"))
-			  (lambda ()
-			    (newline *stderr*)
-			    (tty-reset))))
+			  (let-temporarily (((*s7* 'debug) 0))
+			    (lambda ()
+			      (newline *stderr*)
+			      (tty-reset)))))
 		
 		;; a "normal" terminal -- hopefully it accepts vt100 codes
 		(let ((buf (termios.make)))
@@ -1109,6 +1068,7 @@
 			  (let* ((c (make-string read-size #\null)) 
 				 (cc (string->c-pointer c))
 				 (ctr 0))
+			    (let-temporarily (((*s7* 'debug) 0))
 			    (lambda ()
 			      (call-with-exit
 			       (lambda (return)
@@ -1158,10 +1118,10 @@
 						    (unless (char=? (str pos) #\tab)
 						      (set! max-cols (max max-cols (- pos start)))
 						      (set! start pos)))
-						  (if (< (+ old-pos 1) (length str))
-						      (if (zero? old-pos)
-							  (set! cur-line (copy str))
-							  (set! cur-line (string-append cur-line (substring str (+ old-pos 1))))))
+						  (when (< (+ old-pos 1) (length str))
+						    (set! cur-line (if (zero? old-pos)
+								       (copy str)
+								       (string-append cur-line (substring str (+ old-pos 1))))))
 						  
 						  ;; if the line is too long, the cursor gets confused, so try to reformat long strings
 						  ;;    this still messes up sometimes
@@ -1201,7 +1161,7 @@
 					 
 					 (lambda (type info)
 					   (set! chars 0)
-					   (move-cursor prompt-row prompt-col)
+					   ;(move-cursor prompt-row prompt-col)
 					   (format *stderr* "internal error: ")
 					   (apply format *stderr* info)
 					   (format *stderr* "~%line ~A: ~A~%" ((owlet) 'error-line) ((owlet) 'error-code))
@@ -1214,7 +1174,7 @@
 				 (let ((result (c ctr)))
 				   (set! ctr (+ ctr 1))
 				   result)))))))
-		  
+
 		  (set! input-fd (if (not file) 
 				     terminal-fd
 				     (open file O_RDONLY 0)))
@@ -1250,25 +1210,35 @@
 			  (help chr)))
 		      
 		      (lambda (type info)
-			(move-cursor prompt-row prompt-col)
+			;(move-cursor prompt-row prompt-col)
 			(format *stderr* "internal error: ")
 			(apply format *stderr* info)
 			(format *stderr* "~%line ~A: ~A~%" ((owlet) 'error-line) ((owlet) 'error-code))
 			(set! chars 0)
-			(new-prompt)))))))
-	    
+			(new-prompt))))))))
+
 	    (define* (run file)
-	      ;; check for dumb terminal
-	      (if (or (zero? (isatty terminal-fd))        ; not a terminal -- input from pipe probably
-		      (string=? (getenv "TERM") "dumb"))  ; no vt100 codes -- emacs subjob for example
-		  (emacs-repl)                            ; TODO: restore support for the pipe case
-		  (terminal-repl file)))
+	      ;(when (*s7* 'history-enabled) (fill! (*s7* 'history) ()))
+	      (let-temporarily (((*s7* 'history-enabled) #f))
+		;; check for dumb terminal
+		(if (or (zero? (isatty terminal-fd))        ; not a terminal -- input from pipe probably
+			(string=? (getenv "TERM") "dumb"))  ; no vt100 codes -- emacs subjob for example
+		    (emacs-repl)                            ; TODO: restore support for the pipe case
+		    (terminal-repl file))))
 
 	    (curlet))))))
       
-      (define (save-repl) 
-	(call-with-output-file "save.repl" 
+      (define* (save-repl (file "save.repl"))
+	;; ((*repl* 'save-repl))
+	(call-with-output-file file
 	  (lambda (p) 
+	    (format p ";;; save-repl ~A~%~%" 
+		    (with-let (sublet *libc*)
+		      (let ((timestr (make-string 128))) 
+			(let ((len (strftime timestr 128 "%a %d-%b-%Y %H:%M:%S %Z"
+					     (localtime 
+					      (time.make (time (c-pointer 0 'time_t*)))))))
+			  (substring timestr 0 len)))))
 	    (format p "(for-each~%~NC~
                          (lambda (f)~%~NC~
                            (if (not (provided? f))~%~NC~
@@ -1279,7 +1249,10 @@
 	    (format p "(with-let (*repl* 'repl-let)~%")
 	    (((*repl* 'repl-let) 'write-history) p 2)
 	    (format p ")~%~%")
-	    (format p "~W" (*repl* 'top-level-let)))))
+	    (for-each (lambda (var)
+			(unless (eq? (car var) 'exit)
+			  (format p "(define ~S ~W)~%" (car var) (cdr var))))
+		      (*repl* 'top-level-let)))))
       
       (define (restore-repl) 
 	(set! (*repl* 'top-level-let) (load "save.repl")))  
@@ -1296,14 +1269,50 @@
       (curlet))))
 
 ;; ((*repl* 'run))
+(set! (*s7* 'debug) old-debug)
 
 
 ;;; --------------------------------------------------------------------------------
 
+(define drop-into-repl
+  (let ((depth 0))
+    (lambda (call e)
+      (let ((C-q (integer->char 17)))      ; C-q to exit repl
+	(let-temporarily ((((*repl* 'keymap) C-q) (let-temporarily (((*s7* 'debug) 0)) 
+						    (lambda (c)
+						      (set! depth (- depth 1))
+						      (set! ((*repl* 'repl-let) 'all-done) #t))))
+			  ((*repl* 'top-level-let) e)
+			  ((*repl* 'prompt) (let-temporarily (((*s7* 'debug) 0)) 
+					      (lambda (num) 
+						(with-let (sublet (*repl* 'repl-let) :depth depth)
+						  (set! prompt-string (format #f "break~NC " depth #\>))
+						  (set! prompt-length (length prompt-string)))))))
+	  (set! depth (+ depth 1))
+	  (with-let (sublet (*repl* 'repl-let) :depth depth)
+	    (set! cur-line "")
+	    (set! red-par-pos #f)
+	    (set! cursor-pos 0)
+	    (set! prompt-string (format #f "break~NC " depth #\>))
+	    (set! prompt-length (length prompt-string)))
+	  (format *stderr* "break: ~A, C-q to exit break~%" call)
+	  ((*repl* 'run)))))))
+
+(define (debug.scm-init)
+  (set! ((funclet trace-in) '*debug-repl*) drop-into-repl))
+
+
 (autoload 'lint "lint.scm")
 (autoload 'pretty-print "write.scm")
 (autoload '*libm* "libm.scm")
 (autoload '*libgsl* "libgsl.scm")
+(autoload 'trace "debug.scm")
+(autoload 'untrace "debug.scm")
+(autoload 'break "debug.scm")
+(autoload 'unbreak "debug.scm")
+(autoload 'watch "debug.scm")
+(autoload 'unwatch "debug.scm")
+(autoload 'ow! "stuff.scm")
 
 #|
 (define pwd
@@ -1321,7 +1330,7 @@
 		(let ((timestr (make-string 128))) 
 		  (let ((len (strftime timestr 128 "%a %d-%b-%Y %H:%M:%S %Z"
 				       (localtime 
-					(time.make (time (c-pointer 0)))))))
+					(time.make (time (c-pointer 0 'time_t*)))))))
 		    (substring timestr 0 len)))))))
     (openlet (inlet 'object->string pd 'let-ref-fallback pd))))
 |#
@@ -1351,8 +1360,6 @@
       (inlet 'object->string (lambda args
 			       (system ((*repl* 'repl-let) 'cur-line) #t))))))
 ;; (make-command ls)
-|#
-
 
 (define-macro (time expr)
   (let ((start (gensym)))
@@ -1361,9 +1368,14 @@
        (let ((end ((*libc* 'gettimeofday))))
 	 (+ (- (car end) (car ,start)) ; seconds
 	    (* 0.000001 (- (cadr end) (cadr ,start))))))))
+|#
 
+(define-macro (time expr) 
+  `(let ((start (*s7* 'cpu-time)))
+     ,expr 
+     (- (*s7* 'cpu-time) start)))
 
-(define apropos 
+(define apropos ; this misses syntax names (they aren't in rootlet)
   (let ((levenshtein 
 	 (lambda (s1 s2)
 	   (let ((L1 (length s1))
@@ -1395,7 +1407,7 @@
 	       (make-iterator lt)
 	       (letrec ((iterloop 
 			 (let ((iter (make-iterator lt))
-			       (iterator? #t))
+			       (+iterator+ #t))
 			   (lambda ()
 			     (let ((result (iter)))
 			       (if (and (eof-object? result)
@@ -1409,7 +1421,8 @@
     
     (lambda* (name (e (*repl* 'top-level-let)))
       (let ((ap-name (if (string? name) name 
-			 (if (symbol? name) (symbol->string name)
+			 (if (symbol? name) 
+			     (symbol->string name)
 			     (error 'wrong-type-arg "apropos argument 1 should be a string or a symbol"))))
 	    (ap-env (if (let? e) e 
 			(error 'wrong-type-arg "apropos argument 2 should be an environment"))))
@@ -1504,13 +1517,13 @@
 
 ;;; to display a variable's value as s7 runs using the repl help window:
 ;;;    (define xyz 1) ; some variable...
-;;;    (set! (symbol-setter 'xyz) (lambda (sym val) (set! (*repl* 'helpers) (list (lambda (c) (format #f "xyz: ~S" val)))) val))
+;;;    (set! (setter 'xyz) (lambda (sym val) (set! (*repl* 'helpers) (list (lambda (c) (format #f "xyz: ~S" val)))) val))
 
 
 ;;; --------------------------------------------------------------------------------
 #|
 to work in a particular environment:
-    (set! (*repl* 'top-level-let) (sublet (rootlet) :** #f)) ; or any other like *libc*
+    (set! (*repl* 'top-level-let) (sublet (rootlet))) ; or any other like *libc*
 now (define g 43) puts g in the new top-level-let, so ((rootlet) 'g) -> #<undefined>, and ((*repl* 'top-level-let) 'g) -> 43 (= g in repl of course)
 to start with a fresh top-level, just set top-level-let to (sublet (rootlet)) again.
 
