@@ -287,10 +287,17 @@ void set_mix_color(color_info *color);
   #define widget_modify_bg(W, T, C)
   #define widget_modify_fg(W, T, C)
   #define widget_modify_base(W, T, C)
+#if GTK_CHECK_VERSION(3, 96, 0)
+  #define sg_box_pack_start(Parent, Child, Expand, Fill, Pad) \
+    do {gtk_container_add(GTK_CONTAINER(Parent), Child); gtk_widget_set_hexpand(GTK_WIDGET(Child), Expand); gtk_widget_set_vexpand(GTK_WIDGET(Child), Expand);} while (0)
+  #define sg_box_pack_end(Parent, Child, Expand, Fill, Pad) \
+    do {gtk_container_add(GTK_CONTAINER(Parent), Child); gtk_widget_set_hexpand(GTK_WIDGET(Child), Expand); gtk_widget_set_vexpand(GTK_WIDGET(Child), Expand);} while (0)
+#else
   #define sg_box_pack_start(Parent, Child, Expand, Fill, Pad) \
     do {gtk_box_pack_start(Parent, Child); gtk_widget_set_hexpand(GTK_WIDGET(Child), Expand); gtk_widget_set_vexpand(GTK_WIDGET(Child), Expand);} while (0)
   #define sg_box_pack_end(Parent, Child, Expand, Fill, Pad) \
     do {gtk_box_pack_end(Parent, Child); gtk_widget_set_hexpand(GTK_WIDGET(Child), Expand); gtk_widget_set_vexpand(GTK_WIDGET(Child), Expand);} while (0)
+#endif
   #define sg_widget_set_events(Wid, Ev)
   #define SG_RELIEF_HALF GTK_RELIEF_NORMAL
   #define sg_container_set_border_width(Container, Width)
@@ -371,6 +378,11 @@ cairo_t *make_cairo(GdkDrawable *win);
 #endif
 void free_cairo(cairo_t *cr);
 #endif
+
+#if GTK_CHECK_VERSION(3, 96, 0)
+int snd_strlen(const char *str);
+#endif
+
 void init_gtk(void);
 
 
