@@ -903,11 +903,19 @@ static bool xen_is_colormap(Xen obj)
   return(Xen_c_object_is_type(obj, xen_colormap_tag));
 }
 
-
+#if (!HAVE_SCHEME)
 static void xen_colormap_free(xen_colormap *v) {if (v) free(v);}
 
 Xen_wrap_free(xen_colormap, free_xen_colormap, xen_colormap_free)
-
+#else
+static s7_pointer s7_xen_colormap_free(s7_scheme *sc, s7_pointer obj)
+{
+  xen_colormap *v;
+  v = (xen_colormap *)s7_c_object_value(obj);
+  if (v) free(v);
+  return(NULL);
+}
+#endif
 
 static char *xen_colormap_to_string(xen_colormap *v)
 {
@@ -979,20 +987,24 @@ static Xen new_xen_colormap(int n)
     return(Xen_false);
 
   mx = xen_colormap_make(n);
-  return(Xen_make_object(xen_colormap_tag, mx, 0, free_xen_colormap));
+  return(Xen_make_object(xen_colormap_tag, mx, 0, free_xen_colormap)); /* last 2 args ignored in s7 */
 }
 
 #define C_int_to_Xen_colormap(Val) new_xen_colormap(Val)
 
 
 #if HAVE_SCHEME
-static bool s7_xen_colormap_equalp(void *obj1, void *obj2)
+static s7_pointer s7_xen_colormap_is_equal(s7_scheme *sc, s7_pointer args)
 {
-  return((obj1 == obj2) ||
-	 (((xen_colormap *)obj1)->n == ((xen_colormap *)obj2)->n));
+  s7_pointer p1, p2;
+  p1 = s7_car(args);
+  p2 = s7_cadr(args);
+  if (p1 == p2) return(s7_t(sc));
+  if (s7_c_object_type(p2) == xen_colormap_tag)
+    return(s7_make_boolean(sc, (((xen_colormap *)s7_c_object_value(p1))->n == ((xen_colormap *)s7_c_object_value(p2))->n)));
+  return(s7_f(sc));
 }
 
-
 static Xen s7_xen_colormap_length(s7_scheme *sc, Xen args)
 {
   return(C_int_to_Xen_integer(color_map_size(ss)));
@@ -1016,8 +1028,8 @@ static void init_xen_colormap(void)
 {
 #if HAVE_SCHEME
   xen_colormap_tag = s7_make_c_type(s7, "<colormap>");
-  s7_c_type_set_free(s7, xen_colormap_tag, free_xen_colormap);
-  s7_c_type_set_equal(s7, xen_colormap_tag, s7_xen_colormap_equalp);
+  s7_c_type_set_gc_free(s7, xen_colormap_tag, s7_xen_colormap_free);
+  s7_c_type_set_is_equal(s7, xen_colormap_tag, s7_xen_colormap_is_equal);
   s7_c_type_set_length(s7, xen_colormap_tag, s7_xen_colormap_length);
   s7_c_type_set_ref(s7, xen_colormap_tag, s7_colormap_apply);
   s7_c_type_set_to_string(s7, xen_colormap_tag, g_xen_colormap_to_string);
