@@ -242,6 +242,16 @@ static Xen g_snd_completion(Xen text)
 }
 
 
+#if HAVE_SCHEME
+static void (listener_write)(s7_scheme *sc, uint8_t c, s7_pointer port)
+{
+  char buf[2];
+  buf[0] = c;
+  buf[1] = '\0';
+  listener_append(buf);
+}
+#endif
+
 static Xen g_listener_colorized(void) 
 {
   #define H_listener_colorized "(" S_listener_colorized ") returns #t if the listener is highlighting syntax."
@@ -321,5 +331,7 @@ If it returns true, Snd assumes you've dealt the text yourself, and does not try
   s7_set_setter(s7, ss->listener_prompt_symbol, s7_make_function(s7, "[acc-" S_listener_prompt "]", acc_listener_prompt, 2, 0, false, "accessor"));
   s7_set_documentation(s7, ss->stdin_prompt_symbol, "*stdin-prompt*: the current stdin prompt string");
   s7_set_setter(s7, ss->stdin_prompt_symbol, s7_make_function(s7, "[acc-" S_stdin_prompt "]", acc_stdin_prompt, 2, 0, false, "accessor"));
+
+  s7_define_variable_with_documentation(s7, "*listener-port*", s7_open_output_function(s7, listener_write), "port to write to Snd's listener");
 #endif  
 }
