@@ -445,7 +445,7 @@ static bool move_mark_1(chan_info *cp, mark *mp, int x)
   if (mp->samp < 0) mp->samp = 0;
 
   samps = current_samples(cp);
-  if (mp->samp > samps) mp->samp = samps;
+  if (mp->samp >= samps) mp->samp = samps - 1;
 
   if (Xen_hook_has_list(mark_drag_hook))
     ss->squelch_mark_drag_info = Xen_is_true(run_progn_hook(mark_drag_hook,
@@ -1557,7 +1557,7 @@ static bool move_syncd_mark(chan_info *cp, mark *m, int x)
 		  mp->samp += diff;
 		  if (mp->samp < 0) mp->samp = 0;
 		  samps = current_samples(ncp);
-		  if (mp->samp > samps) mp->samp = samps;
+		  if (mp->samp >= samps) mp->samp = samps - 1;
 		  if (mark_control_clicked)
 		    make_mark_graph(ncp, mark_sd->initial_samples[i], mp->samp, i);
 		  if ((mp->samp >= ap->losamp) && 
@@ -1999,11 +1999,19 @@ bool xen_is_mark(Xen obj)
   return(Xen_c_object_is_type(obj, xen_mark_tag));
 }
 
-
+#if (!HAVE_SCHEME)
 static void xen_mark_free(xen_mark *v) {if (v) free(v);}
 
 Xen_wrap_free(xen_mark, free_xen_mark, xen_mark_free)
-
+#else
+static s7_pointer s7_xen_mark_free(s7_scheme *sc, s7_pointer obj)
+{
+  xen_mark *v;
+  v = (xen_mark *)s7_c_object_value(obj);
+  if (v) free(v);
+  return(NULL);
+}
+#endif
 
 static char *xen_mark_to_string(xen_mark *v)
 {
@@ -2082,7 +2090,7 @@ Xen new_xen_mark(int n)
 #if HAVE_SCHEME
   {
     s7_pointer m;
-    m = Xen_make_object(xen_mark_tag, mx, 0, free_xen_mark);
+    m = Xen_make_object(xen_mark_tag, mx, 0, free_xen_mark); /* last 2 args ignored */
     s7_c_object_set_let(s7, m, g_mark_methods);
     return(m);
   }
@@ -2093,13 +2101,17 @@ Xen new_xen_mark(int n)
 
 
 #if HAVE_SCHEME
-static bool s7_xen_mark_equalp(void *obj1, void *obj2)
+static s7_pointer s7_xen_mark_is_equal(s7_scheme *sc, s7_pointer args)
 {
-  return((obj1 == obj2) ||
-	 (((xen_mark *)obj1)->n == ((xen_mark *)obj2)->n));
+  s7_pointer p1, p2;
+  p1 = s7_car(args);
+  p2 = s7_cadr(args);
+  if (p1 == p2) return(s7_t(sc));
+  if (s7_c_object_type(p2) == xen_mark_tag)
+    return(s7_make_boolean(sc, (((xen_mark *)s7_c_object_value(p1))->n == ((xen_mark *)s7_c_object_value(p2))->n)));
+  return(s7_f(sc));
 }
 
-
 static Xen s7_xen_mark_copy(s7_scheme *sc, s7_pointer args)
 {
   s7_pointer obj;
@@ -2129,8 +2141,8 @@ static void init_xen_mark(void)
   g_mark_methods = s7_openlet(s7, s7_inlet(s7, s7_list(s7, 2, s7_make_symbol(s7, "object->let"), mark_to_let_func)));
   s7_gc_protect(s7, g_mark_methods);
   xen_mark_tag = s7_make_c_type(s7, "<mark>");
-  s7_c_type_set_free(s7, xen_mark_tag, free_xen_mark);
-  s7_c_type_set_equal(s7, xen_mark_tag, s7_xen_mark_equalp);
+  s7_c_type_set_gc_free(s7, xen_mark_tag, s7_xen_mark_free);
+  s7_c_type_set_is_equal(s7, xen_mark_tag, s7_xen_mark_is_equal);
   s7_c_type_set_copy(s7, xen_mark_tag, s7_xen_mark_copy);
   s7_c_type_set_to_string(s7, xen_mark_tag, g_xen_mark_to_string);
 #else
