@@ -675,8 +675,8 @@ void update_possible_selection_in_progress(mus_long_t samp)
 	  ed = cp->edits[cp->edit_ctr];
 	  ed->selection_maxamp = -1.0;
 	  ed->selection_maxamp_position = -1;
-	  if (samp > current_samples(cp))
-	    new_end = current_samples(cp);
+	  if (samp >= current_samples(cp))
+	    new_end = current_samples(cp) - 1;
 	  else new_end = samp;
 
 	  if (new_end < original_beg)
@@ -892,10 +892,19 @@ bool xen_is_selection(Xen obj)
   return(Xen_c_object_is_type(obj, xen_selection_tag));
 }
 
-
+#if (!HAVE_SCHEME)
 static void xen_selection_free(xen_selection *v) {if (v) free(v);}
 
 Xen_wrap_free(xen_selection, free_xen_selection, xen_selection_free)
+#else
+static s7_pointer s7_xen_selection_free(s7_scheme *sc, s7_pointer obj)
+{
+  xen_selection *v;
+  v = (xen_selection *)s7_c_object_value(obj);
+  if (v) free(v);
+  return(NULL);
+}
+#endif
 
 
 static char *xen_selection_to_string(xen_selection *v)
@@ -982,14 +991,17 @@ static Xen s7_xen_selection_length(s7_scheme *sc, Xen args)
   return(g_selection_framples(Xen_undefined, Xen_undefined));
 }
 
-
-static bool s7_xen_selection_equalp(void *obj1, void *obj2)
+static s7_pointer s7_xen_selection_is_equal(s7_scheme *sc, s7_pointer args)
 {
-  return((obj1 == obj2) ||
-	 (((xen_selection *)obj1)->n == ((xen_selection *)obj2)->n));
+  s7_pointer p1, p2;
+  p1 = s7_car(args);
+  p2 = s7_cadr(args);
+  if (p1 == p2) return(s7_t(sc));
+  if (s7_c_object_type(p2) == xen_selection_tag)
+    return(s7_make_boolean(sc, (((xen_selection *)s7_c_object_value(p1))->n == ((xen_selection *)s7_c_object_value(p2))->n)));
+  return(s7_f(sc));
 }
 
-
 static Xen s7_xen_selection_copy(s7_scheme *sc, Xen args)
 {
   if (selection_is_active())
@@ -1049,8 +1061,8 @@ static void init_xen_selection(void)
 {
 #if HAVE_SCHEME
   xen_selection_tag = s7_make_c_type(s7, "<selection>");
-  s7_c_type_set_free(s7, xen_selection_tag, free_xen_selection);
-  s7_c_type_set_equal(s7, xen_selection_tag, s7_xen_selection_equalp);
+  s7_c_type_set_gc_free(s7, xen_selection_tag, s7_xen_selection_free);
+  s7_c_type_set_is_equal(s7, xen_selection_tag, s7_xen_selection_is_equal);
   s7_c_type_set_length(s7, xen_selection_tag, s7_xen_selection_length);
   s7_c_type_set_copy(s7, xen_selection_tag, s7_xen_selection_copy);
   s7_c_type_set_fill(s7, xen_selection_tag, s7_xen_selection_fill);
