@@ -1160,7 +1160,8 @@ void stdin_free_str(void)
 
 static void string_to_stdout(const char *msg, void *ignored)
 {
-  fprintf(stdout, "%s\n", msg);
+  if (msg)
+    fprintf(stdout, "%s\n", msg);
 }
 
 
@@ -1388,22 +1389,22 @@ void check_features_list(const char *features)
 #endif
 
 #if HAVE_RUBY
-  /* provided? is defined in examp.rb */
+  /* provided? is defined in clm.rb */
   Xen_eval_C_string(mus_format("[%s].each do |f|\n\
                                   unless $LOADED_FEATURES.map do |ff| File.basename(ff) end.member?(f.to_s.tr(\"_\", \"-\"))\n\
-                                    $stderr.printf(\"~\\nno %%s!\\n\\n\", f.id2name)\n\
+                                    $stderr.printf(\"\\nno %%s!\\n\\n\", f.id2name)\n\
                                   end\n\
                                 end\n", features));
 #endif
 
 #if HAVE_FORTH
-  Xen_eval_C_string(mus_format("'( %s ) [each] dup \
-                                          provided? [if] \
-                                            drop \
-                                          [else] \
-                                            1 >list \"\\nno %%s!\\n\\n\" swap format .stderr \
-                                          [then] \
-                                        [end-each]\n", 
+  Xen_eval_C_string(mus_format("let: \
+                                  '( %s ) each { f }\
+                                    f provided? unless \
+                                      \"\\nno %%s!\\n\\n\" '( f ) fth-print \
+                                    then \
+                                  end-each \
+                                ;let", 
 			       features)); 
 #endif
   snd_exit(0);
@@ -2957,6 +2958,20 @@ be written, or rely on the default (-1.0 or 1.0 depending on the sign of 'val').
   Xen_define_constant("RTLD_GLOBAL", RTLD_GLOBAL, "dlopen flag");
 #endif
 
+#if HAVE_SCHEME && (!USE_NO_GUI)
+  s7_eval_c_string(s7,
+    "(define debug.scm-init                   \
+       (let ((old-let (top-level-let)))       \
+         (lambda ()                           \
+           (set! ((funclet trace-in) '*debug-port*) *listener-port*) \
+           (set! ((funclet trace-in) '*debug-start-output*) newline) \
+           (set! ((funclet trace-in) '*debug-end-output*) (lambda (p) #f)) \
+           (set! ((funclet trace-in) '*debug-repl*) \
+                  (lambda (call e)                  \
+                    (set! (top-level-let) e)        \
+                    (set! listener-prompt \"break>\"))))))");
+#endif
+
 #if HAVE_LADSPA && HAVE_EXTENSION_LANGUAGE
   g_ladspa_to_snd();
 #endif
