@@ -1,7 +1,7 @@
 #ifndef SND_H
 #define SND_H
 
-#include <mus-config.h>
+#include "mus-config.h"
 
 #include <ctype.h>
 #include <stddef.h>
@@ -55,11 +55,11 @@
 
 #include "snd-strings.h"
 
-#define SND_DATE "31-July-19"
+#define SND_DATE "7-Feb-20"
 #ifndef SND_VERSION
-#define SND_VERSION "19.6"
+#define SND_VERSION "20.1"
 #endif
-#define SND_MAJOR_VERSION "19"
-#define SND_MINOR_VERSION "6"
+#define SND_MAJOR_VERSION "20"
+#define SND_MINOR_VERSION "1"
 
 #endif
