@@ -2,7 +2,7 @@
   ;; depends on running s7test first normally
   (load "s7test-block.so" new-env))
 
-(set! (*s7* 'heap-size) 1024000)
+;(set! (*s7* 'heap-size) 1024000)
 
 (define (test-copy size)
   (let ((old-string (make-string size #\a))
@@ -19,7 +19,7 @@
 
     (do ((i 0 (+ i 1)))
 	((= i size))
-      (hash-table-set! old-hash (string->symbol (number->string i)) #\a))
+      (hash-table-set! old-hash (string->symbol (number->string i)) #\a)) ; gensym is slower, even with "" as prefix 
     (copy old-hash old-let)
 
     (let ((new-string (make-string size #\space))
