@@ -34,7 +34,7 @@
 			  (make-vector '(2 3) "hi") #("hiho" "hi" "hoho") (subvector (make-int-vector '(2 3) 1) 6)
 			  (subvector (subvector (make-float-vector '(2 3) 1.0) 6) '(2 2))
 			  (vector-ref #2d((#(1 2 3)) (#(3 4 5))) 0 0) (define-macro (m a) `(+ ,a 1))
-			  (c-pointer 0) (c-pointer -1) :readable *s7* else (define-bacro* (m (a 1)) `(+ ,a 1))
+			  (c-pointer 0) (c-pointer -1) :readable else (define-bacro* (m (a 1)) `(+ ,a 1))
 			  (byte-vector 0 1 2) (byte-vector) (byte-vector 255 0 127) (make-iterator (vector '(a . 2)))
 			  (lambda (dir) 1.0) (float-vector) (make-float-vector '(2 2)) (int-vector 1 2 3) (int-vector)
 			  (inlet 'value 1 '+ (lambda args 1)) (inlet) (make-iterator (inlet 'a 1 'b 2) (cons #f #f))
@@ -66,36 +66,36 @@
 (define-constant ctrl-chars-len (length ctrl-chars))
 
 (define (test-calls ctrl-str tries size1 op)
-  (let ((x #f) (y #f) (z #f) (pos 0)
-	(cs constants)
-	(cs-len constants-len))
-    (do ((i 0 (+ i 1)))
-	((= i tries))
-      (do ((j 1 (+ j 1)))
-	  ((= j size1))
-	(string-set! ctrl-str j (string-ref ctrl-chars (random ctrl-chars-len))))
-      
-      (set! x (vector-ref cs (random cs-len)))
-      (set! y (vector-ref cs (random cs-len)))
-      (set! z (vector-ref cs (random cs-len)))
-      
-      (object->string x)
-      (display x op)
-      
-      (catch #t (lambda () (format #f "~{~^~S ~} ~{~|~S ~} ~W" x y z)) (lambda arg 'error))
-      (catch #t (lambda () (format #f ctrl-str)) (lambda arg 'error))
-      (catch #t (lambda () (format #f ctrl-str x)) (lambda arg 'error))
-      (catch #t (lambda () (format #f ctrl-str y)) (lambda arg 'error))
-      (catch #t (lambda () (format #f ctrl-str z)) (lambda arg 'error))
-      (set! pos (char-position #\~ ctrl-str 1))
-      (when pos
-	(catch #t (lambda () (format #f ctrl-str x z)) (lambda arg 'error))
-	(catch #t (lambda () (format #f ctrl-str x y)) (lambda arg 'error))
-	(catch #t (lambda () (format #f ctrl-str y z)) (lambda arg 'error))
-	(catch #t (lambda () (format #f ctrl-str z x)) (lambda arg 'error))
-	(when (char-position #\~ ctrl-str (+ pos 1))
-	  (catch #t (lambda () (format #f ctrl-str x y z)) (lambda arg 'error))
-	  (catch #t (lambda () (format #f ctrl-str z y x)) (lambda arg 'error)))))))
+  (do ((i 0 (+ i 1))
+       (x #f) (y #f) (z #f) (pos 0)
+       (cs constants)
+       (cs-len constants-len))
+      ((= i tries))
+    (do ((j 1 (+ j 1)))
+	((= j size1))
+      (string-set! ctrl-str j (string-ref ctrl-chars (random ctrl-chars-len))))
+    
+    (set! x (vector-ref cs (random cs-len)))
+    (set! y (vector-ref cs (random cs-len)))
+    (set! z (vector-ref cs (random cs-len)))
+    
+    (object->string x)
+    (display x op)
+    
+    (catch #t (lambda () (format #f "~{~^~S ~} ~{~|~S ~} ~W" x y z)) (lambda arg 'error))
+    (catch #t (lambda () (format #f ctrl-str)) (lambda arg 'error))
+    (catch #t (lambda () (format #f ctrl-str x)) (lambda arg 'error))
+    (catch #t (lambda () (format #f ctrl-str y)) (lambda arg 'error))
+    (catch #t (lambda () (format #f ctrl-str z)) (lambda arg 'error))
+    (set! pos (char-position #\~ ctrl-str 1))
+    (when pos
+      (catch #t (lambda () (format #f ctrl-str x z)) (lambda arg 'error))
+      (catch #t (lambda () (format #f ctrl-str x y)) (lambda arg 'error))
+      (catch #t (lambda () (format #f ctrl-str y z)) (lambda arg 'error))
+      (catch #t (lambda () (format #f ctrl-str z x)) (lambda arg 'error))
+      (when (char-position #\~ ctrl-str (+ pos 1))
+	(catch #t (lambda () (format #f ctrl-str x y z)) (lambda arg 'error))
+	(catch #t (lambda () (format #f ctrl-str z y x)) (lambda arg 'error))))))
 
 (define (test-chars)
   (let ((op (open-output-string)))
