@@ -2,9 +2,7 @@
 
 (set! (*s7* 'heap-size) (* 4 1024000))
 
-(let ()
-
-  (define with-blocks #f)
+(let ((with-blocks #f))
   (when with-blocks
     (let ((new-env (sublet (curlet) (cons 'init_func 'block_init)))) ; load calls init_func if possible
       (load "s7test-block.so" new-env)))
@@ -98,6 +96,5 @@
      (list 1 10 100 1000 10000 100000 1000000)))
   
   (test)
-  
-  (s7-version)	
+
   (exit))
