@@ -230,4 +230,5 @@
 
 (ft91)
 
-(s7-version)
+(exit)
+
