@@ -13,6 +13,7 @@
 		     ("tread.scm" . "v-read")
 		     ("tmap.scm" . "v-map")
 		     ("tmat.scm" . "v-mat")
+		     ("tmisc.scm" . "v-misc")
 		     ("lg.scm" . "v-lg")
 		     ("titer.scm" . "v-iter")
 		     ("tsort.scm" . "v-sort")
@@ -73,29 +74,30 @@
 	 (system (format #f "./snd compare-calls.scm -e '(compare-calls \"~A~D\" \"~A~D\")'" outfile (- next 1) outfile next)))))
 
    (list (list "repl" "tpeak.scm")
-	 (list "repl" "tmac.scm")
 	 (list "repl" "tauto.scm")
+	 (list "repl" "tref.scm")
 	 (list "repl" "tshoot.scm")
 	 (list "snd -noinit" "make-index.scm")
-	 (list "repl" "tref.scm")
-	 (list "repl" "teq.scm")
 	 (list "repl" "s7test.scm")
-	 (list "repl" "tvect.scm")
 	 (list "repl" "lt.scm")
 	 (list "repl" "tcopy.scm")
-	 (list "repl" "tread.scm")
-	 (list "repl" "tlet.scm")
 	 (list "repl" "tform.scm")
-	 (list "repl" "tfft.scm")
+	 (list "repl" "tmisc.scm")
+	 (list "repl" "tread.scm")
+	 (list "repl" "dup.scm")
+	 (list "repl" "tvect.scm")
 	 (list "repl" "tmat.scm")
-	 (list "repl" "tclo.scm")
 	 (list "repl" "fbench.scm")
 	 (list "repl" "trclo.scm")
-	 (list "repl" "titer.scm")
 	 (list "repl" "tmap.scm")
+	 (list "repl" "titer.scm")
 	 (list "repl" "tsort.scm")
 	 (list "repl" "tset.scm")
-	 (list "repl" "dup.scm")
+	 (list "repl" "tmac.scm")
+	 (list "repl" "teq.scm")
+	 (list "repl" "tfft.scm")
+	 (list "repl" "tlet.scm")
+	 (list "repl" "tclo.scm")
 	 (list "repl" "trec.scm")
 	 (list "repl" "thash.scm")
 	 (list "snd -noinit" "tgen.scm")    ; repl here + cload sndlib was slower
