@@ -8,11 +8,7 @@
 	(*pretty-print-spacing* 2)
 	(*pretty-print-float-format* "~,4F")
 	(*pretty-print-left-margin* 0)
-	(any? (lambda (f sequence) ; this and every? ought to be built-in!
-		(call-with-exit
-		 (lambda (return) 
-		   (for-each (lambda (arg) (if (not (f arg)) (return #f))) sequence)
-		   #t)))))
+	(*pretty-print-cycles* #t))
 
     (define pretty-print-1
       (letrec ((messy-number (lambda (z)
@@ -93,6 +89,12 @@
 			(write-char #\) port))
 		      (write (car p) port))))) ; pretty-print? (it's always a symbol)
 	  
+	  (define (any-let-or-hash-table? sequence)
+	    (and (pair? sequence)
+		 (or (let? (car sequence))
+		     (hash-table? (car sequence))
+		     (any-let-or-hash-table? (cdr sequence)))))
+
 	  (let ((writers 
 		 (let ((h (make-hash-table)))
 		   
@@ -428,38 +430,13 @@
 		   h)))
 	    
 	    ;; pretty-print-1
-	    (lambda (obj port column) 
-	      
+	    (lambda (obj port column)
+
 	      (cond ((number? obj)
 		     (if (rational? obj)
 			 (write obj port)
 			 (display (messy-number obj) port)))
-		    
-		    ((hash-table? obj)
-		     (display "(hash-table" port)
-		     (for-each (lambda (field)
-				 (let ((symstr (object->string (car field))))
-				   (spaces port (+ column 2))
-				   (format port "'(~A . " symstr)
-				   (pretty-print-1 (cdr field) port (+ column 4 (length symstr)))
-				   (write-char #\) port)))
-			       obj)
-		     (write-char #\) port))
-		    
-		    ((let? obj)
-		     (if (and (openlet? obj)
-			      (defined? 'pretty-print obj))
-			 ((obj 'pretty-print) obj port column)
-			 (begin
-			   (display "(inlet" port)
-			   (for-each (lambda (field)
-				       (let ((symstr (symbol->string (car field))))
-					 (spaces port (+ column 2))
-					 (format port ":~A " symstr)
-					 (pretty-print-1 (cdr field) port (+ column 2 (length symstr)))))
-				     obj)
-			   (write-char #\) port))))
-		    
+
 		    ((or (int-vector? obj)
 			 (float-vector? obj))
 		     (if (> (length (vector-dimensions obj)) 1)
@@ -474,11 +451,11 @@
 				 (if (< (- *pretty-print-length* column) 30)
 				     (spaces port column)
 				     (set! column (+ column name-len)))
-				 (do ((len (min (length obj) (let-ref *s7* 'print-length)))
+				 (do ((len (min (length obj) (*s7* 'print-length)))
 				      (col column)
 				      (i 0 (+ i 1)))
 				     ((= i len)
-				      (if (> len (let-ref *s7* 'print-length))
+				      (if (> len (*s7* 'print-length))
 					  (write-string " ...)" port)
 					  (write-char #\) port)))
 				   (let* ((numstr (number->string (obj i)))
@@ -492,6 +469,34 @@
 				     (display numstr port)
 				     (set! col (+ col numlen 1)))))))))
 		    
+		    ((and *pretty-print-cycles*
+			  (pair? (cyclic-sequences obj)))
+		     (format port "~W" obj))
+
+		    ((hash-table? obj)
+		     (display "(hash-table" port)
+		     (for-each (lambda (field)
+				 (let ((symstr (object->string (car field))))
+				   (spaces port (+ column 2))
+				   (format port "'~A " symstr)
+				   (pretty-print-1 (cdr field) port (+ column 4 (length symstr)))))
+			       obj)
+		     (write-char #\) port))
+		    
+		    ((let? obj)
+		     (if (and (openlet? obj)
+			      (defined? 'pretty-print obj))
+			 ((obj 'pretty-print) obj port column)
+			 (begin
+			   (display "(inlet" port)
+			   (for-each (lambda (field)
+				       (let ((symstr (symbol->string (car field))))
+					 (spaces port (+ column 2))
+					 (format port ":~A " symstr)
+					 (pretty-print-1 (cdr field) port (+ column 4 (length symstr)))))
+				     obj)
+			   (write-char #\) port))))
+		    
 		    ((vector? obj)
 		     (if (> (length (vector-dimensions obj)) 1)
 			 (write obj port)
@@ -505,11 +510,11 @@
 				 (if (< (- *pretty-print-length* column) 30)
 				     (spaces port column)
 				     (set! column (+ column 6)))
-				 (do ((len (min (length obj) (let-ref *s7* 'print-length)))
+				 (do ((len (min (length obj) (*s7* 'print-length)))
 				      (col column)
 				      (i 0 (+ i 1)))
 				     ((= i len)
-				      (if (> len (let-ref *s7* 'print-length))
+				      (if (> len (*s7* 'print-length))
 					  (write-string " ...)" port)
 					  (write-char #\) port)))
 				   (let ((olen (length (object->string (obj i)))))
@@ -528,10 +533,7 @@
 		    ((hash-table-ref writers (car obj)) 
 		     => (lambda (f) (f obj port column)))
 		    
-		    ((any? (lambda (p)
-			     (or (hash-table? p)
-				 (let? p)))
-			   obj)
+		    ((any-let-or-hash-table? obj)
 		     (let ((first #t))
 		       (write-char #\( port)
 		       (for-each (lambda (p)
@@ -545,6 +547,15 @@
 			    (strlen (length objstr)))
 		       (if (< (+ column strlen) *pretty-print-length*)
 			   (display objstr port)
+
+			   ;; (format port "~A~A" (cond ((pair-line-number obj) => (lambda (line) (format #f "[~D] " line))) (else "")) objstr)
+			   ;; the other case is above (writers)
+			   ;;    (lambda (f) (format port "[~D]" line) (f obj port column))
+			   ;;    with column check, line check etc
+			   ;; so, the pp/profile hook only needs two calls
+			   ;; (lambda (f obj port column) (f obj port column))
+			   ;; and here (lambda (f obj port column) (f=display obj=objstr port)?
+
 			   (let ((lstlen (length obj)))
 			     
 			     (cond ((or (infinite? lstlen)
@@ -653,9 +664,9 @@
 (define (pp obj)
   (call-with-output-string
    (lambda (p)
-      (if (keyword? obj)
-	  (symbol->string obj)
-	  (pretty-print obj p)))))
+     (if (keyword? obj)
+	 (display obj p)
+	 (pretty-print obj p)))))
 
 #|
 (define (pretty-print-all)
@@ -676,7 +687,7 @@
     (if (pair? form)
 	(if (and (symbol? (car form))
 		 (macro? (symbol->value (car form))))
-	    (expand ((eval (procedure-source (symbol->value (car form)))) form))
+	    (expand (apply macroexpand (list form)))
 	    (cons (expand (car form))
 		  (expand (cdr form))))
 	form))
@@ -685,7 +696,7 @@
 (define* (pp-sequence seq)
   (let ((iter (make-iterator seq))
 	(strs ())
-	(plen (let-ref *s7* 'print-length)))
+	(plen (*s7* 'print-length)))
     (do ((i 0 (+ i 1))
 	 (entry (iterate iter) (iterate iter)))
 	((or (= i plen)
@@ -694,4 +705,26 @@
 	     (apply string-append (append (reverse! strs) (list "...")))
 	     (apply string-append (reverse! strs))))
       (set! strs (cons (format #f "~S " entry) strs)))))
+
+
+;;; pretty-print method:
+(let ((v (openlet (inlet 'value #(0 1 2 3) 
+			 'pretty-print (lambda (obj port column)
+					 (display "#(... 2 ...)" port))))))
+  (pretty-print (list 1 v 3)))
+
+;;; local pretty-print settings:
+(let ((v (openlet (inlet 'value (* pi 1000)
+			 'pretty-print (lambda (obj port column)
+					 (let-temporarily ((((funclet pretty-print) '*pretty-print-float-format*) "~E"))
+					   (pretty-print (obj 'value) port column)))))))
+  (pretty-print (list (* pi 1000) v)))
+
+;;; or simpler:
+(let ((v (* 1000 pi)))
+  (let-temporarily ((((funclet pretty-print) '*pretty-print-float-format*) "~E"))
+    (pretty-print v))
+  (newline)
+  (pretty-print v))
+
 |#
